@@ -4,8 +4,6 @@ use std::fmt::Debug;
 use std::collections::{HashMap};
 use std::hash::Hash;
 
-use crate::one::One;
-
 use crate::basic_matrix::basic_matrix::BasicMatrixTrait;
 use crate::basic_matrix::basic_matrix::
 {
@@ -28,9 +26,9 @@ pub struct SymmetricMatrix<T, V>
 
 
 impl<T, V> BasicMatrixTrait<T, V> for SymmetricMatrix<T, V>
-    where T: Copy + PartialOrd + Sub<Output = T> + Add<Output = T> + Mul<Output = T> + One +
-             Div<Output = T> + Debug + Rem<Output = T> + Eq + Hash + SubAssign + Default + 'static,
-          V: Copy + Default + Debug + PartialEq + MulAssign + 'static,
+    where T: Copy + PartialOrd + Sub<Output = T> + Add<Output = T> + Mul<Output = T> + From<u8> +
+          Div<Output = T> + Debug + Rem<Output = T> + Eq + Hash + SubAssign + 'static,
+          V: Copy + Debug + PartialEq + MulAssign + From<f32> + 'static,
 {
    // fn create_element_value(&mut self, requested_index: T, new_value: V)
     // {
@@ -194,9 +192,9 @@ impl<T, V> BasicMatrixTrait<T, V> for SymmetricMatrix<T, V>
 
 
 impl<T, V> SymmetricMatrix<T, V>
-    where T: Copy + Debug + PartialEq + One + Default + Mul<Output = T> + Add<Output = T> +
+    where T: Copy + Debug + PartialEq + From<u8> + Mul<Output = T> + Add<Output = T> +
              PartialOrd + SubAssign + Div<Output = T> + Sub<Output = T> + Rem<Output = T>,
-          V: Copy + Default
+          V: Copy
 {
     pub fn create(rows_and_columns_number: T, elements_indexes: Vec<T>, elements_values: Vec<V>)
         -> Self
@@ -234,14 +232,14 @@ impl<T, V> SymmetricMatrix<T, V>
                 });
 
         let mut row_column = self.rows_and_columns_number;
-        while row_column > T::default()
+        while row_column > T::from(0u8)
         {
-            row_column -= T::one();
+            row_column -= T::from(1u8);
             let mut answers = Vec::new();
             let mut row = self.rows_and_columns_number;
-            while row > T::default()
+            while row > T::from(0u8)
             {
-                row -= T::one();
+                row -= T::from(1u8);
                 match find_index(row, row_column)
                 {
                     None => answers.push(true),
@@ -249,9 +247,9 @@ impl<T, V> SymmetricMatrix<T, V>
                 }
             }
             let mut column = self.rows_and_columns_number;
-            while column > T::default()
+            while column > T::from(0u8)
             {
-                column -= T::one();
+                column -= T::from(1u8);
                 match find_index(row_column, column)
                 {
                     None => answers.push(true),
@@ -284,14 +282,14 @@ impl<T, V> SymmetricMatrix<T, V>
         {
             if *index % self.rows_and_columns_number > row_column
             {
-                *index -= *index / self.rows_and_columns_number + T::one();
+                *index -= *index / self.rows_and_columns_number + T::from(1u8);
             }
             else
             {
                 *index -= *index / self.rows_and_columns_number;
             }
         }
-        self.rows_and_columns_number -= T::one();
+        self.rows_and_columns_number -= T::from(1u8);
     }
 
 
